/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/

#ifdef __M_THREAD_1_H__
#ifndef __M_THREAD_1_END_H__
#define __M_THREAD_1_END_H__

#ifndef DEADLOCK_CHECK
typedef struct _sem {
	int		tid;
	sem_t		ss;

	char *		lock_file;
	int		lock_line;
	char *		unlock_file;
	int		unlock_line;
} _SEM;

#endif /* DEADLOCK_CHECK */

#endif /* __M_HREAD_1_END_H__ */
#endif /* __M_THREAD_1_H__ */

#ifdef __M_THREAD_2_H__
#ifndef ___M_THREAD_2_END_H___
#define ___M_THREAD_2_END_H___

/*
#define SCHED_POLICY	SCHED_RR
*/
#define SCHED_POLICY	SCHED_OTHER

typedef struct sw_hash {
	struct sw_hash *	next;
	unsigned int		key;
	int			cnt;
	sem_t			sem;
	int			tid;
} SW_HASH;


typedef union thread_block {
	union thread_block * next;
	RW_LOCK		rw_lock;
	_SEM		sem;
	SW_HASH		sw_hash;
} THREAD_BLOCK;


#endif /* __M_THREAD_2_END_H__ */
#endif /* __M_THREAD_2_H__ */
